@@ -2,11 +2,11 @@ package App::Manoc::Controller::APIv1::Ping;
 #ABSTRACT: Controller for Ping test API
 use Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use namespace::autoclean;
 
-BEGIN { extends 'App::Manoc::Controller::APIv1' }
+BEGIN { extends 'App::Manoc::ControllerBase::APIv1' }
 
 
 sub ping : Chained('deserialize') PathPart('ping') Args(0) GET {
@@ -52,7 +52,7 @@ App::Manoc::Controller::APIv1::Ping - Controller for Ping test API
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 ACTIONS
 
