@@ -3,11 +3,10 @@ package App::Manoc::Controller::DHCPServer;
 
 use Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use namespace::autoclean;
-BEGIN { extends 'Catalyst::Controller'; }
-with 'App::Manoc::ControllerRole::CommonCRUD';
+BEGIN { extends 'App::Manoc::ControllerBase::CRUD' }
 
 use App::Manoc::Form::DHCPServer;
 use App::Manoc::Form::DHCPSharedNetwork;
@@ -43,7 +42,7 @@ App::Manoc::Controller::DHCPServer - DHCPServer Controller
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
