@@ -3,7 +3,7 @@ package App::Manoc::DB::Result::Uplink;
 use strict;
 use warnings;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use parent 'App::Manoc::DB::Result';
 
@@ -31,6 +31,34 @@ __PACKAGE__->belongs_to( device => 'App::Manoc::DB::Result::Device', 'device_id'
 __PACKAGE__->set_primary_key('id');
 __PACKAGE__->add_unique_constraints( uplink_dev_if_idx => [ 'device_id', 'interface' ] );
 
+__PACKAGE__->might_have(
+    cabling => 'App::Manoc::DB::Result::CablingMatrix',
+    { 'foreign.hwserver_nic_id' => 'self.id' },
+    {
+        cascade_copy   => 0,
+        cascade_delete => 1,
+        cascade_update => 0,
+    }
+);
+
+sub insert {
+    my ( $self, @args ) = @_;
+
+    my $guard = $self->result_source->schema->txn_scope_guard;
+
+    if ( !defined( $self->name ) ) {
+        my $rs = $self->result_source->resultset;
+        my $count = $rs->search( { serverhw_id => $self->serverhw_id } )->count();
+        $self->name("nic$count");
+    }
+
+    my $r = $self->next::method(@args);
+
+    $guard->commit;
+
+    return $r;
+}
+
 1;
 
 __END__
@@ -43,7 +71,7 @@ App::Manoc::DB::Result::Uplink
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
