@@ -4,7 +4,7 @@ package App::Manoc::DB::Result::VlanVtp;
 use strict;
 use warnings;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use parent 'App::Manoc::DB::Result';
 
@@ -15,6 +15,15 @@ __PACKAGE__->add_columns(
         data_type   => 'int',
         is_nullable => 0
     },
+    vid => {
+        data_type   => 'int',
+        is_nullable => 0
+    },
+    vtp_domain => {
+        data_type   => 'varchar',
+        size        => 64,
+        is_nullable => 0
+    },
     name => {
         data_type   => 'varchar',
         size        => 255,
@@ -23,15 +32,7 @@ __PACKAGE__->add_columns(
 );
 
 __PACKAGE__->set_primary_key('id');
-
-__PACKAGE__->belongs_to(
-    vlan => 'App::Manoc::DB::Result::Vlan',
-    { 'foreign.id' => 'self.id' },
-    {
-        join_type                 => 'LEFT',
-        is_foreign_key_constraint => 0,
-    }
-);
+__PACKAGE__->add_unique_constraints( [ 'vtp_domain', 'vid' ] );
 
 1;
 
@@ -45,7 +46,7 @@ App::Manoc::DB::Result::VlanVtp - A model object representing a VTP info
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
