@@ -4,16 +4,16 @@ package App::Manoc::DB::ResultSet;
 use strict;
 use warnings;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use parent 'DBIx::Class::ResultSet';
 
 # do not load ingnorewantarray helper since it breaks
 # HTML::FormHandler
-
+#
+# also avoid Helper::ResultSet::AutoRemoveColumns
 __PACKAGE__->load_components(
     qw{
-        Helper::ResultSet::AutoRemoveColumns
         Helper::ResultSet::CorrelateRelationship
         Helper::ResultSet::Me
         Helper::ResultSet::NoColumns
@@ -43,7 +43,7 @@ App::Manoc::DB::ResultSet - base class for Manoc dbic resultset classes
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
