@@ -2,18 +2,19 @@ package App::Manoc::DB::ResultSet::WinHostname;
 use strict;
 use warnings;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use parent 'App::Manoc::DB::ResultSet';
 
-use Scalar::Util qw(blessed);
-
 __PACKAGE__->load_components(
     qw/
         +App::Manoc::DB::Helper::ResultSet::TupleArchive
         /
 );
 
+use Scalar::Util qw(blessed);
+use App::Manoc::DB::Search::Result::Hostname;
+
 
 sub register_tuple {
     my $self   = shift;
@@ -28,6 +29,34 @@ sub register_tuple {
 }
 
 
+sub manoc_search {
+    my ( $self, $query, $result ) = @_;
+
+    my $type    = $query->query_type;
+    my $pattern = $query->sql_pattern;
+
+    if ( $type eq 'logon' ) {
+
+        my $rs = $self->search(
+            { name => { '-like' => $pattern } },
+            {
+                order_by => 'name',
+                group_by => 'ipaddr',
+            }
+        );
+
+        while ( my $e = $rs->next ) {
+            my $item = App::Manoc::DB::Search::Result::Hostname->new(
+                ipaddress => $e->ipaddr,
+                hostname  => $e->name,
+                match     => $e->name,
+            );
+            $result->add_item($item);
+        }
+    }
+}
+
+
 1;
 
 # Local Variables:
@@ -47,7 +76,7 @@ App::Manoc::DB::ResultSet::WinHostname
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 METHODS
 
@@ -56,6 +85,10 @@ version 2.99.2
 Overridden in order to convert $params{ipaddr} to
 L<App::Manoc::IPAddress::IPv4> if needed.
 
+=head2 manoc_search(  $query, $result)
+
+Support for Manoc search feature
+
 =head1 SEE ALSO
 
 L<DBIx::Class::ResultSet>
