@@ -2,9 +2,9 @@ package App::Manoc::Form::Base;
 
 use HTML::FormHandler::Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
-extends 'HTML::FormHandler::Model::DBIC';
+extends 'HTML::FormHandler';
 with
     'App::Manoc::Form::TraitFor::Theme',
     'App::Manoc::Form::TraitFor::CSRF';
@@ -47,7 +47,7 @@ App::Manoc::Form::Base
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
