@@ -2,12 +2,11 @@ package App::Manoc::Form::Building;
 
 use HTML::FormHandler::Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
-extends 'App::Manoc::Form::Base';
+extends 'App::Manoc::Form::BaseDBIC';
 
-has '+name'        => ( default => 'form-building' );
-has '+html_prefix' => ( default => 1 );
+has '+name' => ( default => 'form-building' );
 
 has_field 'name' => (
     label    => 'Name',
@@ -56,7 +55,7 @@ App::Manoc::Form::Building
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
