@@ -2,15 +2,14 @@ package App::Manoc::Form::Group;
 
 use HTML::FormHandler::Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use namespace::autoclean;
 
-extends 'App::Manoc::Form::Base';
+extends 'App::Manoc::Form::BaseDBIC';
 with 'App::Manoc::Form::TraitFor::SaveButton';
 
-has '+name'        => ( default => 'form-user' );
-has '+html_prefix' => ( default => 1 );
+has '+name' => ( default => 'form-user' );
 
 has '+item_class' => ( default => 'Group' );
 
@@ -56,7 +55,7 @@ App::Manoc::Form::Group
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
