@@ -2,15 +2,14 @@ package App::Manoc::Form::MngUrlFormat;
 
 use HTML::FormHandler::Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use namespace::autoclean;
 
-extends 'App::Manoc::Form::Base';
+extends 'App::Manoc::Form::BaseDBIC';
 with 'App::Manoc::Form::TraitFor::SaveButton';
 
-has '+name'        => ( default => 'form-mngurlformat' );
-has '+html_prefix' => ( default => 1 );
+has '+name' => ( default => 'form-mngurlformat' );
 
 has_field 'name' => (
     type     => 'Text',
@@ -38,7 +37,7 @@ App::Manoc::Form::MngUrlFormat
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
