@@ -3,7 +3,7 @@ package App::Manoc::Form::TraitFor::RackOptions;
 
 use HTML::FormHandler::Moose::Role;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 
 sub get_rack_options {
@@ -14,13 +14,13 @@ sub get_rack_options {
         {
             join     => 'building',
             prefetch => 'building',
-            order_by => 'me.name'
+            order_by => [ 'me.building_id', 'me.name' ]
         }
     );
 
     return map +{
         value => $_->id,
-        label => $_->label,
+        label => $_->label
         },
         $racks->all();
 }
@@ -45,7 +45,7 @@ App::Manoc::Form::TraitFor::RackOptions - Role for populating rack selections
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 METHDOS
 
