@@ -3,12 +3,14 @@ package App::Manoc::Form::Types;
 use strict;
 use warnings;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use MooseX::Types -declare => [ 'MacAddress', ];
 
 use MooseX::Types::Moose ( 'Str', 'Num', 'Int' );
 
+use App::Manoc::Utils qw(normalize_mac_addr);
+
 
 
 subtype MacAddress, as Str, where {
@@ -16,15 +18,7 @@ subtype MacAddress, as Str, where {
 }, message { "Not a valid mac address in aa:bb:cc:dd:ff format" };
 
 coerce MacAddress, from Str, via {
-    /^([0-9a-fA-F]{2})([0-9a-fA-F]{2})[-:]?([0-9a-fA-F]{2})([0-9a-fA-F]{2})[-:]?([0-9a-fA-F]{2})([0-9a-fA-F]{2})$/
-        and
-        return lc
-        ("$1:$2:$3:$4:$5:$6");
-
-    /^[0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}[-:][0-9a-fA-F]{2}$/
-        and
-        return lc
-        ($_);
+    return normalize_mac_addr($_);
 };
 
 1;
@@ -45,7 +39,7 @@ App::Manoc::Form::Types - Manoc form types
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 DESCRIPTION
 
