@@ -1,13 +1,12 @@
 package App::Manoc::Form::User::ChangePassword;
 
 use HTML::FormHandler::Moose;
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
-extends 'App::Manoc::Form::Base';
+extends 'App::Manoc::Form::BaseDBIC';
 with 'App::Manoc::Form::TraitFor::SaveButton';
 
-has '+name'        => ( default => 'form-user' );
-has '+html_prefix' => ( default => 1 );
+has '+name' => ( default => 'form-user' );
 
 has_field 'old_password' => (
     type     => 'Password',
@@ -55,7 +54,7 @@ App::Manoc::Form::User::ChangePassword
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
