@@ -2,13 +2,12 @@ package App::Manoc::Form::User::SetPassword;
 
 use HTML::FormHandler::Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
-extends 'App::Manoc::Form::Base';
+extends 'App::Manoc::Form::BaseDBIC';
 with 'App::Manoc::Form::TraitFor::SaveButton';
 
-has '+name'        => ( default => 'form-user' );
-has '+html_prefix' => ( default => 1 );
+has '+name' => ( default => 'form-user' );
 
 has_field 'password' => (
     type      => 'Password',
@@ -42,7 +41,7 @@ App::Manoc::Form::User::SetPassword
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
