@@ -1,18 +1,17 @@
 package App::Manoc::Form::VirtualInfr;
 use HTML::FormHandler::Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use namespace::autoclean;
 
-extends 'App::Manoc::Form::Base';
+extends 'App::Manoc::Form::BaseDBIC';
 with
     'App::Manoc::Form::TraitFor::SaveButton',
     'App::Manoc::Form::TraitFor::Horizontal';
 
-has '+item_class'  => ( default => 'VirtualInfr' );
-has '+name'        => ( default => 'form-virtualinfr' );
-has '+html_prefix' => ( default => 1 );
+has '+item_class' => ( default => 'VirtualInfr' );
+has '+name'       => ( default => 'form-virtualinfr' );
 
 has_field 'name' => (
     type  => 'Text',
@@ -41,7 +40,7 @@ App::Manoc::Form::VirtualInfr
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
