@@ -5,7 +5,7 @@ package App::Manoc::Model::ManocDB;
 use Moose;
 extends 'Catalyst::Model::DBIC::Schema';
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use namespace::autoclean;
 
@@ -13,34 +13,15 @@ __PACKAGE__->config( schema_class => 'App::Manoc::DB', );
 
 has 'search_engine' => (
     is      => 'ro',
-    isa     => 'App::Manoc::Search::Engine',
+    isa     => 'App::Manoc::DB::Search',
     lazy    => 1,
     builder => '_build_search_engine',
 );
 
-sub _build_search_engine {
-    my $self = shift;
-    return App::Manoc::Search::Engine->new( { schema => $self->schema } );
-}
-
 
 sub search {
-    my ( $self, $query_string, $params ) = @_;
-
-    my $engine = $self->search_engine;
-
-    my $q = App::Manoc::Search::Query->new( { search_string => $query_string } );
-
-    # use params to refine query
-    if ( $params->{limit} && !defined( $q->limit ) ) {
-        $q->limit( ( $params->{limit} ) );
-    }
-    if ( $params->{type} && !defined( $q->query_type ) ) {
-        $q->query_type( $params->{type} );
-    }
-    $q->parse;
-
-    return $engine->search($q);
+    my $self = shift;
+    return $self->schema->manoc_search(@_);
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -56,7 +37,7 @@ App::Manoc::Model::ManocDB - Catalyst DBIC Schema Model for Manoc
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 DESCRIPTION
 
@@ -66,7 +47,7 @@ L<Catalyst::Model::DBIC::Schema> Model using schema L<App::Manoc::DB>
 
 =head2 search( $query_string, $params )
 
-Run query using L<App::Manoc::Search::Engine>.
+Run query using L<App::Manoc::DB> C<manoc_search> method.
 
 =head1 AUTHORS
 
