@@ -3,7 +3,7 @@ package App::Manoc::Netwalker::Poller::DeviceTask;
 
 use Moose;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use Try::Tiny;
 
@@ -94,7 +94,7 @@ with 'App::Manoc::Netwalker::Poller::BaseTask', 'App::Manoc::Logger::Role';
 sub _build_arp_vlan {
     my $self = shift;
 
-    my $vlan = $self->nwinfo->arp_vlan->id ||
+    my $vlan = $self->nwinfo->arp_vlan->vid ||
         $self->config->default_vlan;
     return defined($vlan) ? $vlan : 1;
 }
@@ -238,6 +238,8 @@ sub _build_uplinks {
     my $source     = $self->source;
     my $device_set = $self->device_set;
 
+    return unless $source->can('neighbors');
+
     my %uplinks;
 
     # get uplink from CDP
@@ -358,7 +360,12 @@ sub update_device_info {
     $nw_entry->vendor( $source->vendor );
     $nw_entry->serial( $source->serial );
 
-    $nw_entry->vtp_domain( $source->vtp_domain );
+    if ( $source->can('vtp_domain') ) {
+        $nw_entry->vtp_domain( $source->vtp_domain );
+    }
+    else {
+        $nw_entry->vtp_domain(undef);
+    }
     $nw_entry->boottime( $source->boottime || 0 );
 
     $nw_entry->update;
@@ -371,10 +378,12 @@ sub update_cdp_neighbors {
     my $source      = $self->source;
     my $entry       = $self->device_entry;
     my $schema      = $self->schema;
-    my $neighbors   = $source->neighbors;
     my $new_dev     = 0;
     my $cdp_entries = 0;
 
+    return unless $source->can('neighbors');
+
+    my $neighbors = $source->neighbors;
     while ( my ( $p, $n ) = each(%$neighbors) ) {
         foreach my $s (@$n) {
             my $from_dev_id = $entry->id;
@@ -425,20 +434,43 @@ sub update_if_table {
     my $entry        = $self->device_entry;
     my $iface_filter = $self->config->{iface_filter};
 
+    return unless $source->can('ifstatus_table');
+
     my $ifstatus_table = $source->ifstatus_table;
 
     # delete old infos
-    $entry->ifstatus()->delete;
+    foreach my $interface ( $entry->interfaces ) {
+        $interface->status()->delete;
+
+        if ( exists $ifstatus_table->{ $interface->name } ) {
+
+            if ( $interface->autocreated ) {
+                $interface->delete;
+            }
+            else {
+                $interface->nw_confirmed(0);
+                $interface->update();
+            }
+        }
+    }
+
     # update
     foreach my $port ( keys %$ifstatus_table ) {
         $iface_filter && lc($port) =~ /^(vlan|null|unrouted vlan)/o and next;
+
         my $ifstatus = $ifstatus_table->{$port};
-        $entry->add_to_ifstatus(
-            {
-                interface => $port,
-                %$ifstatus
-            }
-        );
+        my $interface = $entry->find_or_new_related( interfaces => { name => $port } );
+        $interface->nw_confirmed(1);
+        if ( !$interface->in_storage ) {
+            $interface->autocreated(1);
+            $interface->insert;
+        }
+        else {
+            $interface->update();
+        }
+
+        # $ifstatus is supposed to have the same fields as DeviceIfStatus
+        $interface->create_related( status => $ifstatus );
     }
 }
 
@@ -494,7 +526,8 @@ sub update_vtp_database {
     my $source = $self->source;
     my $entry  = $self->device_entry;
 
-    my $vlan_db = $source->vtp_database;
+    my $vtp_domain = $source->vtp_domain;
+    my $vlan_db    = $source->vtp_database;
 
     $self->log->info( "getting vtp info from ", $entry->mng_address );
     if ( !defined($vlan_db) ) {
@@ -506,12 +539,13 @@ sub update_vtp_database {
     $self->task_report->add_warning("Vtp Vlan DB up to date");
 
     my $rs = $self->schema->resultset('VlanVtp');
-    $rs->delete();
+    $rs->search( { vtp_domain => $vtp_domain } )->delete();
     while ( my ( $id, $name ) = each(%$vlan_db) ) {
         $rs->find_or_create(
             {
-                'id'   => $id,
-                'name' => $name
+                'vid'        => $id,
+                'name'       => $name,
+                'vtp_domain' => $vtp_domain,
             }
         );
     }
@@ -600,7 +634,7 @@ App::Manoc::Netwalker::Poller::DeviceTask - Device poller task
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 ATTRIBUTES
 
