@@ -3,20 +3,26 @@ package App::Manoc::Support;
 use strict;
 use warnings;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use FindBin;
 
 BEGIN {
     local $^W = 0;
-    my $support_dir = "$FindBin::Bin/../support/";
 
-    if ( -d $support_dir ) {
+    my @paths = ( "$FindBin::Bin/../perl5", "$FindBin::Bin/../../perl5", "/opt/manoc/perl5" );
+
+    foreach my $support_dir (@paths) {
+
+        next unless -d $support_dir;
+
         eval "use local::lib '$support_dir'";
         unless ($@) {
             delete $INC{"File/Path.pm"};
             require "File/Path.pm";    ## no critic
         }
+
+        last;
     }
 }
 
@@ -32,7 +38,7 @@ App::Manoc::Support
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 AUTHORS
 
