@@ -3,7 +3,7 @@ package App::Manoc::View::JSON;
 use strict;
 use warnings;
 
-our $VERSION = '2.99.2'; ##TRIAL VERSION
+our $VERSION = '2.99.3'; ##TRIAL VERSION
 
 use base 'Catalyst::View::JSON';
 
@@ -13,6 +13,24 @@ use JSON qw();
 __PACKAGE__->config( 'expose_stash' => 'json_data', );
 
 
+sub encode_json {
+    my ( $self, $c, $data ) = @_;
+
+    if ( not defined($data) ) {
+        $c->response->status(403);
+        $c->detach();
+        return;
+    }
+
+    my $encoder = JSON::MaybeXS->new(
+        utf8            => 1,
+        allow_blessed   => 1,
+        convert_blessed => 1,
+    );
+    return $encoder->encode($data);
+}
+
+
 1;
 # Local Variables:
 # mode: cperl
@@ -31,7 +49,7 @@ App::Manoc::View::JSON
 
 =head1 VERSION
 
-version 2.99.2
+version 2.99.3
 
 =head1 SYNOPSIS
 
@@ -48,21 +66,6 @@ App::Manoc::View::JSON - Catalyst JSON View
 
 =for Pod::Coverage encode_json
 
-sub encode_json {
-    my ( $self, $c, $data ) = @_;
-
-    if ( not defined($data) ) {
-        $c->response->status(403);
-        $c->detach();
-        return;
-    }
-
-    my $encoder = JSON->new->utf8();
-    $encoder->allow_blessed(1);
-    $encoder->convert_blessed(1);
-    return $encoder->encode($data);
-}
-
 =head1 SEE ALSO
 
 L<Catalyst::View::JSON>
